# tuko 

- Promise based Node module for Geckoboard's datasets API. 
- Requires Node >=6 
- Only standard library dependencies! (Uses `https` instead of e.g. the some-what heavy `request` module).
- *tuko is the Waray word for [gecko](https://war.wikipedia.org/wiki/Tuko)*

## Usage

```
npm i tuko -S
```

The import returns a function that expects your Geckoboard API key which in turn returns the client.

```
const gb = require('tuko')(GECKOBOARD_API_KEY);
```

## API

### Methods:

- `ping()` 
- `create(id, schema)` 
- `update(id, data)` 
- `del(id)` 

#### `gb.ping()` 

Sends a GET request to the datasets API root to check if all is well (e.g. with your API key)

```
gb.ping()
.then(res => console.log('All is well'));
```

#### `gb.create(id, schema)` 

Create a new dataset. `id` is a string, and `schema` is an object with a `fields` property:


```
gb.create('rainbows', { 
  fields: {
    date: { type: 'date', name: 'date' },
    count: { type: 'number', name: 'count' }
  }
})
.then(res => console.log(res));
```

#### `gb.update(id, data)` 

Update a dataset with data. `id` is the dataset's string name, and `data` is an object with a `data` property with an array value:

```
gb.update('rainbows', {
  data: [
    { date: '2016-07-09', count: 100 }
  ]
})
.then(res => console.log(res));
```

#### `gb.del(id)` 

Delete a dataset. `id` is the the dataset's string name.

```
gb.del('rainbows')
.then(res => console.log(res));
```
