const https = require('https');
const { version } = require('./package');

module.exports = function client(key) {
  const req = (method, path, body) => {
    return request({ 
      auth: `${key}:`, 
      method, path, body 
    });
  }
  return {
    ping: () => req('GET', '/'),
    create: (id, schema) => req('PUT', `/datasets/${id}`, schema),
    update: (id, data) => req('PUT', `/datasets/${id}/data`, data),
    del: (id) => req('DELETE', `/datasets/${id}`)
  }
}

function request(options) {
  return new Promise((resolve, reject) => {
    const { body, path, method, auth } = options;
    const json = JSON.stringify(body) || '';
    const opts = {
      auth,
      path,
      method,
      port: 443,
      hostname: 'api.geckoboard.com',
      headers: {
        'Content-Type': 'application/json',
        'User-Agent': `Tuko Node Client ${version}`,
        'Content-length': Buffer.byteLength(json),
      },
    };
    const req = https.request(opts, res => {
      res.setEncoding('utf8');
      let raw = '', parsed;
      res.on('data', chunk => raw += chunk);
      res.on('end', () => {
        const status = res.statusCode;
        if (status < 200 || status >= 300) {
          return reject({ status, error: raw });
        }
        try {
          parsed = JSON.parse(raw);
          resolve(parsed);
        } catch (error) {
          reject({ error, raw });
        }
      });
      res.on('error', error => reject({ error }));
    });
    req.write(json);
    req.end();
    req.on('error', error => reject({ error }));
  });
}
